@@ -52,7 +52,8 @@ class Clusterer(OptionHandler):
         self.enforce_type(jobject, "weka.clusterers.Clusterer")
         super(Clusterer, self).__init__(jobject=jobject, options=options)
 
-    def get_capabilities(self):
+    @property
+    def capabilities(self):
         """
         Returns the capabilities of the clusterer.
         :return: the capabilities
@@ -109,6 +110,7 @@ class Clusterer(OptionHandler):
         pred = javabridge.call(self.jobject, "distributionForInstance", "(Lweka/core/Instance;)[D", inst.jobject)
         return javabridge.get_env().get_double_array_elements(pred)
 
+    @property
     def number_of_clusters(self):
         """
         Returns the number of clusters found.
@@ -117,6 +119,7 @@ class Clusterer(OptionHandler):
         """
         return javabridge.call(self.jobject, "numberOfClusters", "()I")
 
+    @property
     def graph_type(self):
         """
         Returns the graph type if classifier implements weka.core.Drawable, otherwise -1.
@@ -128,6 +131,7 @@ class Clusterer(OptionHandler):
         else:
             return -1
 
+    @property
     def graph(self):
         """
         Returns the graph if classifier implements weka.core.Drawable, otherwise None.
@@ -160,15 +164,8 @@ class SingleClustererEnhancer(Clusterer):
         self.enforce_type(jobject, "weka.clusterers.SingleClustererEnhancer")
         super(SingleClustererEnhancer, self).__init__(classname=classname, jobject=jobject, options=options)
 
-    def set_clusterer(self, clusterer):
-        """
-        Sets the base clusterer.
-        :param clusterer: the base clusterer to use
-        :type clusterer: Clusterer
-        """
-        javabridge.call(self.jobject, "setClusterer", "(Lweka/clusterers/Clusterer;)V", clusterer.jobject)
-
-    def get_clusterer(self):
+    @property
+    def clusterer(self):
         """
         Returns the base clusterer.
         :return: the clusterer
@@ -176,6 +173,15 @@ class SingleClustererEnhancer(Clusterer):
         """
         return Clusterer(javabridge.call(self.jobject, "getClusterer", "()Lweka/clusterers/Clusterer;"))
 
+    @clusterer.setter
+    def clusterer(self, clusterer):
+        """
+        Sets the base clusterer.
+        :param clusterer: the base clusterer to use
+        :type clusterer: Clusterer
+        """
+        javabridge.call(self.jobject, "setClusterer", "(Lweka/clusterers/Clusterer;)V", clusterer.jobject)
+
 
 class FilteredClusterer(SingleClustererEnhancer):
     """
@@ -196,15 +202,8 @@ class FilteredClusterer(SingleClustererEnhancer):
         self.enforce_type(jobject, classname)
         super(FilteredClusterer, self).__init__(classname=classname, jobject=jobject, options=options)
 
-    def set_filter(self, filtr):
-        """
-        Sets the filter.
-        :param filtr: the filter to use
-        :type filtr: Filter
-        """
-        javabridge.call(self.jobject, "setFilter", "(Lweka/filters/Filter;)V", filtr.jobject)
-
-    def get_filter(self):
+    @property
+    def filter(self):
         """
         Returns the filter.
         :return: the filter
@@ -212,6 +211,15 @@ class FilteredClusterer(SingleClustererEnhancer):
         """
         return Filter(javabridge.call(self.jobject, "getFilter", "()Lweka/filters/Filter;"))
 
+    @filter.setter
+    def filter(self, filtr):
+        """
+        Sets the filter.
+        :param filtr: the filter to use
+        :type filtr: Filter
+        """
+        javabridge.call(self.jobject, "setFilter", "(Lweka/filters/Filter;)V", filtr.jobject)
+
 
 class ClusterEvaluation(JavaObject):
     """
@@ -240,7 +248,8 @@ class ClusterEvaluation(JavaObject):
         """
         javabridge.call(self.jobject, "evaluateClusterer", "(Lweka/core/Instances;)V", test.jobject)
 
-    def get_cluster_results(self):
+    @property
+    def cluster_results(self):
         """
         The cluster results as string.
         :return: the results string
@@ -248,7 +257,8 @@ class ClusterEvaluation(JavaObject):
         """
         return javabridge.call(self.jobject, "clusterResultsToString", "()Ljava/lang/String;")
 
-    def get_cluster_assignments(self):
+    @property
+    def cluster_assignments(self):
         """
         Return an array of cluster assignments corresponding to the most recent set of instances clustered.
         :return: the cluster assignments
@@ -260,7 +270,8 @@ class ClusterEvaluation(JavaObject):
         else:
             return javabridge.get_env().get_double_array_elements(array)
 
-    def get_num_clusters(self):
+    @property
+    def num_clusters(self):
         """
         Returns the number of clusters.
         :return: the number of clusters
@@ -268,7 +279,8 @@ class ClusterEvaluation(JavaObject):
         """
         return javabridge.call(self.jobject, "getNumClusters", "()I")
 
-    def get_log_likelihood(self):
+    @property
+    def log_likelihood(self):
         """
         Returns the log likelihood.
         :return: the log likelihood
@@ -276,7 +288,8 @@ class ClusterEvaluation(JavaObject):
         """
         return javabridge.call(self.jobject, "getLogLikelihood", "()D")
 
-    def get_classes_to_clusters(self):
+    @property
+    def classes_to_clusters(self):
         """
         Return the array (ordered by cluster number) of minimum error class to cluster mappings..
         :return: the mappings
@@ -356,7 +369,7 @@ def main():
     try:
         clusterer = Clusterer(classname=parsed.clusterer)
         if len(parsed.option) > 0:
-            clusterer.set_options(parsed.option)
+            clusterer.options = parsed.option
         print(ClusterEvaluation.evaluate_clusterer(clusterer, params))
     except Exception, e:
         print(e)
