@@ -33,7 +33,8 @@ class Package(JavaObject):
         self.enforce_type(jobject, "org.pentaho.packageManagement.Package")
         super(Package, self).__init__(jobject)
 
-    def get_name(self):
+    @property
+    def name(self):
         """
         Returns the name of the package.
         :return: the name
@@ -41,7 +42,8 @@ class Package(JavaObject):
         """
         return javabridge.call(self.jobject, "getName", "()Ljava/lang/String;")
 
-    def get_url(self):
+    @property
+    def url(self):
         """
         Returns the URL of the package.
         :return: the url
@@ -49,7 +51,8 @@ class Package(JavaObject):
         """
         return str(JavaObject(javabridge.call(self.jobject, "getPackageURL", "()Ljava/net/URL;")))
 
-    def get_dependencies(self):
+    @property
+    def dependencies(self):
         """
         Returns the dependencies of the package.
         :return: the list of Dependency objects
@@ -62,7 +65,8 @@ class Package(JavaObject):
             result.append(Dependency(dependency))
         return result
 
-    def get_metadata(self):
+    @property
+    def metadata(self):
         """
         Returns the meta-data.
         :return: the meta-data dictionary
@@ -71,6 +75,7 @@ class Package(JavaObject):
         return javabridge.get_dictionary_wrapper(
             javabridge.call(self.jobject, "getPackageMetaData", "()Ljava/util/Map;"))
 
+    @property
     def is_installed(self):
         """
         Returns whether the package is installed.
@@ -147,16 +152,8 @@ class Dependency(JavaObject):
         self.enforce_type(jobject, "org.pentaho.packageManagement.Dependency")
         super(Dependency, self).__init__(jobject)
 
-    def set_source(self, pkge):
-        """
-        Sets the source package.
-        :param pkge: the package
-        :type pkge: Package
-        """
-        javabridge.call(
-            self.jobject, "setSource", "(Lorg/pentaho/packageManagement/Package;)V", pkge.jobject)
-
-    def get_source(self):
+    @property
+    def source(self):
         """
         Returns the source package.
         :return: the package
@@ -165,16 +162,18 @@ class Dependency(JavaObject):
         return Package(
             javabridge.call(self.jobject, "getSource", "()Lorg/pentaho/packageManagement/Package;"))
 
-    def set_target(self, constr):
+    @source.setter
+    def source(self, pkge):
         """
-        Sets the target package constraint.
-        :param constr: the package constraint
-        :type constr: Package
+        Sets the source package.
+        :param pkge: the package
+        :type pkge: Package
         """
         javabridge.call(
-            self.jobject, "setTarget", "(Lorg/pentaho/packageManagement/PackageConstraint;)V", constr.jobject)
+            self.jobject, "setSource", "(Lorg/pentaho/packageManagement/Package;)V", pkge.jobject)
 
-    def get_target(self):
+    @property
+    def target(self):
         """
         Returns the target package constraint.
         :return: the package constraint
@@ -183,6 +182,16 @@ class Dependency(JavaObject):
         return PackageConstraint(
             javabridge.call(self.jobject, "getTarget", "()Lorg/pentaho/packageManagement/PackageConstraint;"))
 
+    @target.setter
+    def target(self, constr):
+        """
+        Sets the target package constraint.
+        :param constr: the package constraint
+        :type constr: Package
+        """
+        javabridge.call(
+            self.jobject, "setTarget", "(Lorg/pentaho/packageManagement/PackageConstraint;)V", constr.jobject)
+
 
 def establish_cache():
     """
@@ -192,7 +201,7 @@ def establish_cache():
         "weka/core/WekaPackageManager", "establishCacheIfNeeded", "([Ljava/io/PrintStream;)Ljava/lang/Exception;", [])
 
 
-def get_all_packages():
+def all_packages():
     """
     Returns a list of all packages.
     :return: the list of packages
@@ -208,7 +217,7 @@ def get_all_packages():
     return result
 
 
-def get_available_packages():
+def available_packages():
     """
     Returns a list of all packages that aren't installed yet.
     :return: the list of packages
@@ -224,7 +233,7 @@ def get_available_packages():
     return result
 
 
-def get_installed_packages():
+def installed_packages():
     """
     Returns a list of the installed packages.
     :return: the list of packages
@@ -289,9 +298,9 @@ def is_installed(name):
     :return: whether the package is installed
     :rtype: bool
     """
-    pkgs = get_installed_packages()
+    pkgs = installed_packages()
     for pkge in pkgs:
-        if pkge.get_name() == name:
+        if pkge.name == name:
             return True
     return False
 
@@ -304,36 +313,36 @@ if __name__ == "__main__":
 
         print("All packages")
         print("============")
-        packages = get_all_packages()
+        packages = all_packages()
         for pkg in packages:
-            print(pkg.get_name())
-            print("  url: " + pkg.get_url())
+            print(pkg.name)
+            print("  url: " + pkg.url)
             print("")
 
         print("Available packages")
         print("==================")
-        packages = get_available_packages()
+        packages = available_packages()
         p = packages[0]
         for pkg in packages:
-            print(pkg.get_name())
-            print("  url: " + pkg.get_url())
+            print(pkg.name)
+            print("  url: " + pkg.url)
             print("")
 
         print("Installed packages")
         print("==================")
-        packages = get_installed_packages()
+        packages = installed_packages()
         for pkg in packages:
-            print(pkg.get_name())
-            print("  url: " + pkg.get_url())
+            print(pkg.name)
+            print("  url: " + pkg.url())
             print("")
 
         print("Install/Uninstall")
         print("=================")
-        print("Install: " + p.get_name())
-        print(install_package(p.get_url()))
+        print("Install: " + p.name)
+        print(install_package(p.url))
 
-        print("Uninstall: " + p.get_name())
-        uninstall_package(p.get_name())
+        print("Uninstall: " + p.name)
+        uninstall_package(p.name)
     except Exception, e:
         print(e)
     finally:
